package com.njyunzhi.servsummary.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.ResponseBean;
import com.njyunzhi.servsummary.common.SMSCaptcha;
import com.njyunzhi.servsummary.common.StringUtils;
import com.njyunzhi.servsummary.entity.SysUser;
import com.njyunzhi.servsummary.vo.LoginParm;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

@Api(tags = "通用登录接口")
@RestController
@RequestMapping("/")
public class LoginController extends BaseController {

    @Autowired
    SMSCaptcha smsCaptcha;

    @PostMapping("/login")
    @ApiOperation(value="登录", notes = "登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody LoginParm loginParm) throws Exception {

        if (StringUtils.isEmpty(loginParm.getPhone()) || StringUtils.isEmpty(loginParm.getCaptcha())) {
            return ResponseBean.error("手机号或者验证码不能为空");
        }

        String err = smsCaptcha.validate(loginParm.getPhone(), loginParm.getCaptcha());
        if (err != null) {
            return ResponseBean.error(err);
        }

        SysUser sysUser = sysUserService.getExistBy("phone", loginParm.getPhone(), false, true);
        if (null == sysUser) {
            return ResponseBean.error("手机号码不正确");
        }

        StpUtil.login(sysUser.getUserId(), "admin");
        String tokenValue = StpUtil.getTokenValue();

        Map<String, Object> result = new HashMap<>();
        result.put("user", sysUser);
        result.put("token", tokenValue);

        return ResponseBean.success(result);
    }
}
