package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaEcs;
import com.njyunzhi.servsummary.service.TaEcsService;

 /**
 * 服务器;(ta_ecs)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "服务器对象功能接口")
@RestController
@RequestMapping("/")
public class TaEcsController extends BaseController {
    
    @Autowired
    private TaEcsService taEcsService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param ecsId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taEcs/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taEcsService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taEcs")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaEcs> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaEcs> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaEcs> result = taEcsService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taEcs 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taEcs")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaEcs taEcs) throws Exception {
        taEcsService.save(taEcs);
        return ResponseBean.success(taEcs);
    }
    
    /** 
     * 更新数据
     *
     * @param taEcs 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taEcs/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaEcs taEcs,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taEcsService.updateById(taEcs);
        return ResponseBean.success(taEcs);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param ecsId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taEcs/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taEcsService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}