package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaOssBucket;
import com.njyunzhi.servsummary.service.TaOssBucketService;

 /**
 * OSS Bucket;(ta_oss_bucket)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "OSS Bucket对象功能接口")
@RestController
@RequestMapping("/")
public class TaOssBucketController extends BaseController {
    
    @Autowired
    private TaOssBucketService taOssBucketService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param bucketId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taOssBucket/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taOssBucketService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taOssBucket")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaOssBucket> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaOssBucket> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaOssBucket> result = taOssBucketService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taOssBucket 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taOssBucket")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaOssBucket taOssBucket) throws Exception {
        taOssBucketService.save(taOssBucket);
        return ResponseBean.success(taOssBucket);
    }
    
    /** 
     * 更新数据
     *
     * @param taOssBucket 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taOssBucket/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaOssBucket taOssBucket,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taOssBucketService.updateById(taOssBucket);
        return ResponseBean.success(taOssBucket);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param bucketId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taOssBucket/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taOssBucketService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}