package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.Constants;
import com.njyunzhi.servsummary.common.ResponseBean;

import java.util.List;

import com.njyunzhi.servsummary.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaPlatform;
import com.njyunzhi.servsummary.service.TaPlatformService;

/**
 * 云平台;(ta_platform)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "云平台对象功能接口")
@RestController
@RequestMapping("/")
public class TaPlatformController extends BaseController {

    @Autowired
    private TaPlatformService taPlatformService;

    /**
     * 通过ID查询单条数据
     *
     * @param cloudId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taPlatform/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taPlatformService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taPlatform")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) throws Exception {

        IPage<TaPlatform> pg = new Page<>(pageNum, pageSize);
//        QueryWrapper<TaPlatform> queryWrapper = new QueryWrapper<>();
//        queryWrapper.gt("status", Constants.STATUS_DELETE);
//        queryWrapper.eq(null != status, "status", status);
//        queryWrapper.like(!StringUtils.isEmpty(url), "url", url);
//        queryWrapper.orderByAsc("expire_date");
        IPage<TaPlatform> result = taPlatformService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param taPlatform 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taPlatform")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaPlatform taPlatform) throws Exception {
        taPlatformService.save(taPlatform);
        return ResponseBean.success(taPlatform);
    }

    /**
     * 更新数据
     *
     * @param taPlatform 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taPlatform/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaPlatform taPlatform,
                             @ApiParam("对象ID") @PathVariable String id) throws Exception {
        taPlatformService.updateById(taPlatform);
        return ResponseBean.success(taPlatform);
    }

    /**
     * 通过主键删除数据
     *
     * @param cloudId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taPlatform/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taPlatformService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}