package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaService;
import com.njyunzhi.servsummary.service.TaServiceService;

 /**
 * 服务表;(ta_service)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "服务表对象功能接口")
@RestController
@RequestMapping("/")
public class TaServiceController extends BaseController {
    
    @Autowired
    private TaServiceService taServiceService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param serviceId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taService/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taServiceService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taService")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaService> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaService> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaService> result = taServiceService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taService 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taService")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaService taService) throws Exception {
        taServiceService.save(taService);
        return ResponseBean.success(taService);
    }
    
    /** 
     * 更新数据
     *
     * @param taService 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taService/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaService taService,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taServiceService.updateById(taService);
        return ResponseBean.success(taService);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param serviceId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taService/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taServiceService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}