package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.Constants;
import com.njyunzhi.servsummary.common.ResponseBean;
import java.util.List;

import com.njyunzhi.servsummary.common.StringUtils;
import com.njyunzhi.servsummary.entity.TaPlatform;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaSsl;
import com.njyunzhi.servsummary.service.TaSslService;

 /**
 * ssl域名;(ta_ssl)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "ssl域名对象功能接口")
@RestController
@RequestMapping("/")
public class TaSslController extends BaseController {
    
    @Autowired
    private TaSslService taSslService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param sslId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taSsl/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taSslService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taSsl")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("URL") @RequestParam(value = "url", required = false) String url,
                             @ApiParam("状态") @RequestParam(value = "status", required = false) Integer status) throws Exception {
        
        IPage<TaSsl> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSsl> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.eq(null != status, "status", status);
        queryWrapper.like(!StringUtils.isEmpty(url), "url", url);
        queryWrapper.orderByAsc("expire_date");
        IPage<TaSsl> result = taSslService.page(pg, queryWrapper);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taSsl 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taSsl")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaSsl taSsl) throws Exception {
        if (StringUtils.isEmpty(taSsl.getUrl())) {
            return ResponseBean.error("域名不能为空");
        }

        TaSsl exist = taSslService.getExistBy("url", taSsl.getUrl(), false, true);
        if (exist != null) {
            return ResponseBean.error("域名已存在");
        }

        taSslService.save(taSsl);
        return ResponseBean.success(taSsl);
    }
    
    /** 
     * 更新数据
     *
     * @param taSsl 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taSsl/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaSsl taSsl,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taSsl.setSslId(id);

        if (StringUtils.isEmpty(taSsl.getUrl())) {
            return ResponseBean.error("域名不能为空");
        }

        TaSsl exist = taSslService.getExistBy("url", taSsl.getUrl(), false, true);
        if (exist != null && !exist.getSslId().equals(id)) {
            return ResponseBean.error("域名已存在");
        }

        taSslService.updateById(taSsl);
        return ResponseBean.success(taSsl);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param sslId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taSsl/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taSslService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}